/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "qmldesignercorelib_global.h"
#include "plaintexteditmodifier.h"

#include <texteditor/texteditor.h>

#include <QStringList>

namespace QmlJS { class Snapshot; }

namespace QmlDesigner {

class QMLDESIGNERCORE_EXPORT BaseTextEditModifier: public PlainTextEditModifier
{
public:
    BaseTextEditModifier(TextEditor::TextEditorWidget *textEdit);

    void indentLines(int startLine, int endLine) override;
    void indent(int offset, int length) override;

    TextEditor::TabSettings tabSettings() const override;

    bool renameId(const QString &oldId, const QString &newId) override;
    bool moveToComponent(int nodeOffset) override;
    QStringList autoComplete(QTextDocument *textDocument, int position, bool explicitComplete) override;

private:
    TextEditor::TextEditorWidget *m_textEdit;
};

} // namespace QmlDesigner
